EncoderBuffer

Type Alias EncoderBuffer 

pub type EncoderBuffer = WrappedDracoObject<EncoderBuffer>;

Aliased Type

pub struct EncoderBuffer(/* private fields */);

Implementations

Source

impl EncoderBuffer

pub fn new() -> Self

pub fn as_mut_ptr(&mut self) -> *mut EncoderBuffer

pub fn clear(&mut self)

pub fn resize(&mut self, size: i64)

pub fn data(&self) -> *const c_char

Returns a pointer to the data in the buffer

pub fn size(&self) -> usize

pub fn as_slice(&self) -> &[u8]

Returns a slice of the buffer

Safety

The pointer must be valid for the lifetime of the buffer