pub struct EncoderOptionsBase;Expand description
autocxx bindings couldn’t be generated: This function or method uses a type where one of the template parameters was incomprehensible to bindgen/autocxx - probably because it uses template specialization.