pub type DecoderBuffer = WrappedDracoObject<DecoderBuffer>;Aliased Type
pub struct DecoderBuffer(/* private fields */);Implementations
Sourceimpl DecoderBuffer
impl DecoderBuffer
pub fn new() -> Self
Sourcepub unsafe fn from_buffer_ptr(data_ptr: *const c_char, size: usize) -> Self
pub unsafe fn from_buffer_ptr(data_ptr: *const c_char, size: usize) -> Self
Initializes the decoder buffer with a raw data pointer and size
Safety
The data pointer must be valid for the lifetime of the decoder buffer
Sourcepub fn from_buffer(data_buffer: &[u8]) -> Self
pub fn from_buffer(data_buffer: &[u8]) -> Self
Initializes the decoder buffer with a slice of data
Safety
The given slice must be valid for the lifetime of the decoder buffer
Sourcepub fn from_encoder_buffer(encoder_buffer: &mut EncoderBuffer) -> Self
pub fn from_encoder_buffer(encoder_buffer: &mut EncoderBuffer) -> Self
Initializes the decoder buffer with the data from the encoder buffer
Examples found in repository?
examples/encode_decode.rs (line 58)
31fn main() -> io::Result<()> {
32 let points = gen_points();
33
34 ////////// BUINDING //////////
35 let mut builder = PointCloudBuilder::new(points.len() as u32);
36
37 let attr_id = builder.add_attribute(
38 ffi::draco::GeometryAttribute_Type::POSITION,
39 3,
40 ffi::draco::DataType::DT_FLOAT64,
41 );
42
43 for (i, point) in points.iter().enumerate() {
44 builder.add_point(attr_id, i, point);
45 }
46 let mut pc = builder.build(false);
47
48 println!("after building");
49 print_pc(&mut pc, attr_id);
50
51 ////////// ENCODE //////////
52 let mut encoder = Encoder::new()
53 .set_speed_options(5, 5)
54 .set_attribute_quantization(ffi::draco::GeometryAttribute_Type::POSITION, 14);
55
56 if let Ok(mut buffer) = pc.to_buffer(&mut encoder) {
57 ////////// DECODE //////////
58 let mut buf = DecoderBuffer::from_encoder_buffer(&mut buffer);
59 let pc_decoded = PointCloud::from_buffer(&mut Decoder::new(), &mut buf);
60
61 if let Ok(mut pc_decoded) = pc_decoded {
62 println!("after decoding");
63 print_pc(&mut pc_decoded, attr_id);
64 } else {
65 println!("Failed to decode point cloud");
66 }
67 }
68 Ok(())
69}