pub type EncoderBuffer = WrappedDracoObject<EncoderBuffer>;
pub struct EncoderBuffer(/* private fields */);
Returns a pointer to the data in the buffer
Returns a slice of the buffer
The pointer must be valid for the lifetime of the buffer